[Slim-Checkins] r12657 - /trunk/server/Slim/Buttons/XMLBrowser.pm

andy at svn.slimdevices.com andy at svn.slimdevices.com
Tue Aug 21 19:12:36 PDT 2007


Author: andy
Date: Tue Aug 21 19:12:36 2007
New Revision: 12657

URL: http://svn.slimdevices.com?rev=12657&view=rev
Log:
Fix type=text items that were not bumping properly because they matched the hasDescription check

Modified:
    trunk/server/Slim/Buttons/XMLBrowser.pm

Modified: trunk/server/Slim/Buttons/XMLBrowser.pm
URL: http://svn.slimdevices.com/trunk/server/Slim/Buttons/XMLBrowser.pm?rev=12657&r1=12656&r2=12657&view=diff
==============================================================================
--- trunk/server/Slim/Buttons/XMLBrowser.pm (original)
+++ trunk/server/Slim/Buttons/XMLBrowser.pm Tue Aug 21 19:12:36 2007
@@ -497,12 +497,11 @@
 				$itemURL = $item->{'value'};
 			}
 
 			# Allow text-only items that RadioTime uses
 			if ( $item->{'type'} && $item->{'type'} eq 'text' ) {
-				undef $itemURL;
-			}
-			
-			if ( $item->{'search'} || $item->{'type'} eq 'search' ) {
+				$client->bumpRight();
+			}
+			elsif ( $item->{'search'} || $item->{'type'} eq 'search' ) {
 				
 				my $title;
 				
@@ -593,7 +592,7 @@
 				);
 
 			}
-			elsif (hasDescription($item)) {
+			elsif ( hasDescription($item) ) {
 
 				displayItemDescription($client, $item);
 
@@ -497,12 +497,11 @@
 			}
 
-			# Allow text-only items that RadioTime uses
+			# Allow text-only items that go nowhere and just bump
 			if ( $item->{'type'} && $item->{'type'} eq 'text' ) {



More information about the checkins mailing list